using ImageSharp.Segmentations.Binarizations;
namespace ImageSharpApp.AlgProcessor
{
    class GeoSeamCarvingParams : IAlgParameters
    {
        public int NWidth = 0;
        public int NHeight = 0;
        public IntRange NWidthRange = null;
        public IntRange NHeightRange = null;

        public GeoSeamCarvingParams(int width, int height)
        {
            this.NWidth = width;
            this.NHeight = height;
            this.NWidthRange = new IntRange(1, 2 * width);
            this.NHeightRange = new IntRange(1, 2 * height);
        }
    }

    class GrayContrastAdaptParams : IAlgParameters
    {
        public int PxPercLow = 10;
        public int PxPercHigh = 10;
        public IntRange PxPercLowRange = new IntRange(0, 100);
        public IntRange PxPercHighRange = new IntRange(0, 100);
    };

    class GrayContrastStretchParams : IAlgParameters
    {
        public byte GrayOld1 = 100;
        public byte GrayNew1 = 60;
        public byte GrayOld2 = 155;
        public byte GrayNew2 = 195;
        public ByteRange GrayRange = new ByteRange(0, 255);
    }

    class GrayGammaCorrectionParams : IAlgParameters
    {
        public float Gamma = 1.0f;
        public byte A0 = 10;
        public FloatRange GammaRange = new FloatRange(0f, 20.0f);
        public ByteRange A0Range = new ByteRange(0, 255);
    };

    class GrayLUTParams : IAlgParameters
    {
        public byte[] LUT = new byte[256];
    }

    class GrayFunctionParams : IAlgParameters
    {
        public ImageSharp.GrayValueTransforms.FunctionApplication.TransformFunction TransFunc = null;
    }

    class GrayHistSpecParams : IAlgParameters
    {
        public int[] Hist = new int[256];
    }

    class GrayHistLocalEqParams : IAlgParameters
    {
        public int MaskWidth = 7;
        public IntRange MaskWidthRange = new IntRange(1, 100);
    }

    class SegThreshParams : IAlgParameters
    {
        public byte Threshold = 128;
        public ByteRange ThreshRange = new ByteRange(0, 255);
    }

    class SegADBParams : IAlgParameters
    {
        public ADBinarization.GanglionCell[] GCells =
                {   new ADBinarization.GanglionCell(7, 1),
                    new ADBinarization.GanglionCell(3, 1),
                    new ADBinarization.GanglionCell(3, 0),
                    new ADBinarization.GanglionCell(1, 0),
                };
    }

    class FilterAdapGaussParams : IAlgParameters
    {
        public double Sigma = 1.0;
        public DoubleRange SigmaRange = new DoubleRange(0.0, 20.0);
    }

    class FilterLinearParams : IAlgParameters
    {
        public double[,] FilterMatrix = new double[3, 3];
    }

    class FilterNonLinMedianParams : IAlgParameters
    {
        public int MaskWidth = 3;
        public IntRange MaskWidthRange = new IntRange(1, 100);
    }

    class FilterNonLinISEFParams : IAlgParameters
    {
        public float SmoothingFactor = 0.5f;
        public FloatRange SmoothingRange = new FloatRange(0f, 1f);
    }
    
    class FilterNonLinUnsharpParams : IAlgParameters
    {
        public double Sigma = 1.0;
        public double Intensity = 2.0;
        public DoubleRange SigmaRange = new DoubleRange(0.0, 20.0);
        public DoubleRange IntensityRange = new DoubleRange(0.0, 10.0);
    }

    class FilterNonLinHighboostParams : IAlgParameters
    {
        public double Sigma = 1.0;
        public DoubleRange SigmaRange = new DoubleRange(0.0, 20.0);
    }

    class FilterSpectralLoGParams : IAlgParameters
    {
        public double Sigma = 1.5;
        public DoubleRange SigmaRange = new DoubleRange(0.0, 20.0);
    }

    class FilterSpectralBandpassParams : IAlgParameters
    {
        public int Min = 10;
        public int Max = 60;
        public IntRange MinRange = new IntRange(0, 100);
        public IntRange MaxRange = new IntRange(0, 100);

        public void SetRanges(int width, int height)
        {
            // Bildhhe und -breite muss Zweierpotenz sein -> nimm Maximum als Filtergrenze
            int maxf = (int)System.Math.Max(width, height);
            int i = 1;
            while (i < maxf)
                i *= 2;
            this.MinRange = new IntRange(0, i);
            this.MaxRange = new IntRange(0, i);
        }
    }

    class FilterSpectralLowpassParams : IAlgParameters
    {
        public int Cutoff = 60;
        public IntRange CutoffRange = new IntRange(0, 100);

        public void SetRanges(int width, int height)
        {
            // Bildhhe und -breite muss Zweierpotenz sein -> nimm Maximum als Filtergrenze
            int maxf = (int)System.Math.Max(width, height);
            int i = 1;
            while (i < maxf)
                i *= 2;
            this.CutoffRange = new IntRange(0, i);
        }
    }

    class FilterSpectralHighpassParams : IAlgParameters
    {
        public int Cutoff = 10;
        public IntRange CutoffRange = new IntRange(0, 100);

        public void SetRanges(int width, int height)
        {
            // Bildhhe und -breite muss Zweierpotenz sein -> nimm Maximum als Filtergrenze
            int maxf = (int)System.Math.Max(width, height);
            int i = 1;
            while (i < maxf)
                i *= 2;
            this.CutoffRange = new IntRange(0, i);
        }
    }

    class FilterSpectralSmoothBandpassParams : IAlgParameters
    {
        public int Min = 10;
        public int Max = 60;
        public int Omega1 = 5;
        public int Omega2 = 5;
        public IntRange MinRange = new IntRange(0, 100);
        public IntRange MaxRange = new IntRange(0, 100);
        public IntRange Omega1Range = new IntRange(0, 50);
        public IntRange Omega2Range = new IntRange(0, 50);

        public void SetRanges(int width, int height)
        {
            // Bildhhe und -breite muss Zweierpotenz sein -> nimm Maximum als Filtergrenze
            int maxf = (int)System.Math.Max(width, height);
            int i = 1;
            while (i < maxf)
                i *= 2;
            this.MinRange = new IntRange(0, i);
            this.MaxRange = new IntRange(0, i);
            this.Omega1Range = new IntRange(0, i / 2);
            this.Omega2Range = new IntRange(0, i / 2);
        }
    }

    class FilterSpectralSmoothLowpassParams : IAlgParameters
    {
        public int Cutoff = 60;
        public int Omega = 5;
        public IntRange CutoffRange = new IntRange(0, 100);
        public IntRange OmegaRange = new IntRange(0, 50);

        public void SetRanges(int width, int height)
        {
            // Bildhhe und -breite muss Zweierpotenz sein -> nimm Maximum als Filtergrenze
            int maxf = (int)System.Math.Max(width, height);
            int i = 1;
            while (i < maxf)
                i *= 2;
            this.CutoffRange = new IntRange(0, i);
            this.OmegaRange = new IntRange(0, i / 2);
        }
    }

    class FilterSpectralSmoothHighpassParams : IAlgParameters
    {
        public int Cutoff = 10;
        public int Omega = 5;
        public IntRange CutoffRange = new IntRange(0, 100);
        public IntRange OmegaRange = new IntRange(0, 50);

        public void SetRanges(int width, int height)
        {
            // Bildhhe und -breite muss Zweierpotenz sein -> nimm Maximum als Filtergrenze
            int maxf = (int)System.Math.Max(width, height);
            int i = 1;
            while (i < maxf)
                i *= 2;
            this.CutoffRange = new IntRange(0, i);
            this.OmegaRange = new IntRange(0, i / 2);
        }
    }

    class EdgesCannyParams : IAlgParameters
    {
        public float Sigma = 2.0f;
        public byte ThreshLow = 50;
        public byte ThreshHigh = 100;
        public bool AutoThresh = false;
        public bool GradOnly = false;
        public FloatRange SigmaRange = new FloatRange(0f, 20f);
        public ByteRange GrayRange = new ByteRange(0, 255);
    }

    class EdgesShenCastanParams : IAlgParameters
    {
        public float SmoothFac = 0.6f;
        public byte ThreshLow = 20;
        public byte ThreshHigh = 70;
        public int WinWidth = 5;
        public int ThinFactor = 1;
        public FloatRange SmoothRange = new FloatRange(0f, 1f);
        public ByteRange GrayRange = new ByteRange(0, 255);
        public IntRange WindowRange = new IntRange(2, 20);
        public IntRange ThinRange = new IntRange(1, 10);
    }

    class EdgesMarrHildrethParams : IAlgParameters
    {
        public double Sigma = 2.0f;
        public DoubleRange SigmaRange = new DoubleRange(0.0, 20.0);
    }
}