using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ImageSharpApp.AlgProcessor.Forms
{
    partial class EdgesCannyForm : Form
    {
        private bool userChanged = false;
        private EdgesCannyParams pars = null;

        public EdgesCannyParams Params
        {
            get
            {
                return this.pars;
            }
        }

        public EdgesCannyForm(EdgesCannyParams pars)
        {
            InitializeComponent();

            this.pars = pars;

            this.userChanged = false;
            trackBarSigma.Minimum = (int)(pars.SigmaRange.Min * numericUpDownSigma.DecimalPlaces * 10f);
            trackBarSigma.Maximum = (int)(pars.SigmaRange.Max * numericUpDownSigma.DecimalPlaces * 10f);
            trackBarSigma.Value = (int)(pars.Sigma * numericUpDownSigma.DecimalPlaces * 10f);
            trackBarSigma.TickStyle = TickStyle.None;
            numericUpDownSigma.Minimum = (decimal)pars.SigmaRange.Min;
            numericUpDownSigma.Maximum = (decimal)pars.SigmaRange.Max;
            numericUpDownSigma.Value = (decimal)pars.Sigma;
            trackBarThreshLow.Minimum = (int)pars.GrayRange.Min;
            trackBarThreshLow.Maximum = (int)pars.GrayRange.Max;
            trackBarThreshLow.Value = (int)pars.ThreshLow;
            trackBarThreshLow.TickStyle = TickStyle.None;
            numericUpDownThreshLow.Minimum = (decimal)pars.GrayRange.Min;
            numericUpDownThreshLow.Maximum = (decimal)pars.GrayRange.Max;
            numericUpDownThreshLow.Value = (decimal)pars.ThreshLow;
            trackBarThreshHigh.Minimum = (int)pars.GrayRange.Min;
            trackBarThreshHigh.Maximum = (int)pars.GrayRange.Max;
            trackBarThreshHigh.Value = (int)pars.ThreshHigh;
            trackBarThreshHigh.TickStyle = TickStyle.None;
            numericUpDownThreshHigh.Minimum = (decimal)pars.GrayRange.Min;
            numericUpDownThreshHigh.Maximum = (decimal)pars.GrayRange.Max;
            numericUpDownThreshHigh.Value = (decimal)pars.ThreshHigh;
            this.userChanged = true;
            checkBoxGradOnly.Checked = pars.GradOnly;
            checkBoxThresh.Checked = pars.AutoThresh;
        }

        public EdgesCannyForm()
        {
            InitializeComponent();
        }

        private void trackBarSigma_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                float sigma = trackBarSigma.Value / (numericUpDownSigma.DecimalPlaces * 10f);
                this.pars.Sigma = sigma;
                numericUpDownSigma.Value = (decimal)Math.Min(this.pars.SigmaRange.Max, Math.Max(this.pars.SigmaRange.Min, sigma));
                userChanged = true;
            }
        }

        private void numericUpDownSigma_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                float sigma = (float)numericUpDownSigma.Value;
                this.pars.Sigma = sigma;
                trackBarSigma.Value = (int)Math.Min(this.pars.SigmaRange.Max * numericUpDownSigma.DecimalPlaces * 10, Math.Max(this.pars.SigmaRange.Min * numericUpDownSigma.DecimalPlaces * 10, sigma * numericUpDownSigma.DecimalPlaces * 10));
                userChanged = true;
            }
        }

        private void trackBarThreshLow_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                byte thresh = (byte)trackBarThreshLow.Value;
                this.pars.ThreshLow = thresh;
                numericUpDownThreshLow.Value = Math.Min(this.pars.GrayRange.Max, Math.Max(this.pars.GrayRange.Min, thresh));
                userChanged = true;
            }
        }

        private void numericUpDownThreshLow_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                byte thresh = (byte)numericUpDownThreshLow.Value;
                this.pars.ThreshLow = thresh;
                trackBarThreshLow.Value = Math.Min(this.pars.GrayRange.Max, Math.Max(this.pars.GrayRange.Min, thresh));
                userChanged = true;
            }
        }

        private void trackBarThreshHigh_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                byte thresh = (byte)trackBarThreshHigh.Value;
                this.pars.ThreshHigh = thresh;
                numericUpDownThreshHigh.Value = Math.Min(this.pars.GrayRange.Max, Math.Max(this.pars.GrayRange.Min, thresh));
                userChanged = true;
            }
        }

        private void numericUpDownThreshHigh_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                byte thresh = (byte)numericUpDownThreshHigh.Value;
                this.pars.ThreshHigh = thresh;
                trackBarThreshHigh.Value = Math.Min(this.pars.GrayRange.Max, Math.Max(this.pars.GrayRange.Min, thresh));
                userChanged = true;
            }
        }

        private void checkBoxThresh_CheckedChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                groupBoxThresh.Enabled = !checkBoxThresh.Checked;
                pars.AutoThresh = checkBoxThresh.Checked;
            }
        }

        private void checkBoxGradOnly_CheckedChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                groupBoxThresh.Enabled = !checkBoxThresh.Checked && !checkBoxGradOnly.Checked;
                checkBoxThresh.Enabled = !checkBoxGradOnly.Checked;
                pars.GradOnly = checkBoxGradOnly.Checked;
            }
        }

        private void buttonOK_Click(object sender, EventArgs e)
        {
            if (checkBoxThresh.Checked)
            {
                pars.AutoThresh = true;
            }
            this.DialogResult = DialogResult.OK;
            this.Dispose();
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Dispose();
        }
    }
}