using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ImageSharpApp.AlgProcessor.Forms
{
    partial class EdgesShenCastanForm : Form
    {
        private bool userChanged = false;
        private EdgesShenCastanParams pars = null;

        public EdgesShenCastanParams Params
        {
            get
            {
                return this.pars;
            }
        }

        public EdgesShenCastanForm(EdgesShenCastanParams pars)
        {
            InitializeComponent();

            this.pars = pars;

            this.userChanged = false;
            trackBarSmooth.Minimum = (int)(pars.SmoothRange.Min * numericUpDownSmooth.DecimalPlaces * 10f);
            trackBarSmooth.Maximum = (int)(pars.SmoothRange.Max * numericUpDownSmooth.DecimalPlaces * 10f);
            trackBarSmooth.Value = (int)(pars.SmoothFac * numericUpDownSmooth.DecimalPlaces * 10f);
            trackBarSmooth.TickStyle = TickStyle.None;
            numericUpDownSmooth.Minimum = (decimal)pars.SmoothRange.Min;
            numericUpDownSmooth.Maximum = (decimal)pars.SmoothRange.Max;
            numericUpDownSmooth.Value = (decimal)pars.SmoothFac;
            trackBarThreshLow.Minimum = (int)pars.GrayRange.Min;
            trackBarThreshLow.Maximum = (int)pars.GrayRange.Max;
            trackBarThreshLow.Value = (int)pars.ThreshLow;
            trackBarThreshLow.TickStyle = TickStyle.None;
            numericUpDownThreshLow.Minimum = (decimal)pars.GrayRange.Min;
            numericUpDownThreshLow.Maximum = (decimal)pars.GrayRange.Max;
            numericUpDownThreshLow.Value = (decimal)pars.ThreshLow;
            trackBarThreshHigh.Minimum = (int)pars.GrayRange.Min;
            trackBarThreshHigh.Maximum = (int)pars.GrayRange.Max;
            trackBarThreshHigh.Value = (int)pars.ThreshHigh;
            trackBarThreshHigh.TickStyle = TickStyle.None;
            numericUpDownThreshHigh.Minimum = (decimal)pars.GrayRange.Min;
            numericUpDownThreshHigh.Maximum = (decimal)pars.GrayRange.Max;
            numericUpDownThreshHigh.Value = (decimal)pars.ThreshHigh;
            trackBarWinWidth.Minimum = pars.WindowRange.Min;
            trackBarWinWidth.Maximum = pars.WindowRange.Max;
            trackBarWinWidth.Value = pars.WinWidth;
            trackBarWinWidth.TickStyle = TickStyle.None;
            numericUpDownWinWidth.Minimum = (decimal)pars.WindowRange.Min;
            numericUpDownWinWidth.Maximum = (decimal)pars.WindowRange.Max;
            numericUpDownWinWidth.Value = (decimal)pars.WinWidth;
            trackBarThinFac.Minimum = pars.ThinRange.Min;
            trackBarThinFac.Maximum = pars.ThinRange.Max;
            trackBarThinFac.Value = pars.ThinFactor;
            trackBarThinFac.TickStyle = TickStyle.None;
            numericUpDownThinFac.Minimum = (decimal)pars.ThinRange.Min;
            numericUpDownThinFac.Maximum = (decimal)pars.ThinRange.Max;
            numericUpDownThinFac.Value = (decimal)pars.ThinFactor;
            this.userChanged = true;
        }

        public EdgesShenCastanForm()
        {
            InitializeComponent();
        }

        private void trackBarSmooth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                float smooth = trackBarSmooth.Value / (numericUpDownSmooth.DecimalPlaces * 10f);
                this.pars.SmoothFac = smooth;
                numericUpDownSmooth.Value = (decimal)Math.Min(this.pars.SmoothRange.Max, Math.Max(this.pars.SmoothRange.Min, smooth));
                userChanged = true;
            }
        }

        private void numericUpDownSmooth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                float smooth = (float)numericUpDownSmooth.Value;
                this.pars.SmoothFac = smooth;
                trackBarSmooth.Value = (int)Math.Min(this.pars.SmoothRange.Max * numericUpDownSmooth.DecimalPlaces * 10, Math.Max(this.pars.SmoothRange.Min * numericUpDownSmooth.DecimalPlaces * 10, smooth * numericUpDownSmooth.DecimalPlaces * 10));
                userChanged = true;
            }
        }

        private void trackBarThreshLow_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                byte thresh = (byte)trackBarThreshLow.Value;
                this.pars.ThreshLow = thresh;
                numericUpDownThreshLow.Value = Math.Min(this.pars.GrayRange.Max, Math.Max(this.pars.GrayRange.Min, thresh));
                userChanged = true;
            }
        }

        private void numericUpDownThreshLow_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                byte thresh = (byte)numericUpDownThreshLow.Value;
                this.pars.ThreshLow = thresh;
                trackBarThreshLow.Value = Math.Min(this.pars.GrayRange.Max, Math.Max(this.pars.GrayRange.Min, thresh));
                userChanged = true;
            }
        }

        private void trackBarThreshHigh_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                byte thresh = (byte)trackBarThreshHigh.Value;
                this.pars.ThreshHigh = thresh;
                numericUpDownThreshHigh.Value = Math.Min(this.pars.GrayRange.Max, Math.Max(this.pars.GrayRange.Min, thresh));
                userChanged = true;
            }
        }

        private void numericUpDownThreshHigh_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                byte thresh = (byte)numericUpDownThreshHigh.Value;
                this.pars.ThreshHigh = thresh;
                trackBarThreshHigh.Value = Math.Min(this.pars.GrayRange.Max, Math.Max(this.pars.GrayRange.Min, thresh));
                userChanged = true;
            }
        }

        private void trackBarWinWidth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int width = trackBarWinWidth.Value;
                this.pars.WinWidth = width;
                numericUpDownWinWidth.Value = Math.Min(this.pars.WindowRange.Max, Math.Max(this.pars.WindowRange.Min, width));
                userChanged = true;
            }
        }

        private void numericUpDownWinWidth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int width = (int)numericUpDownWinWidth.Value;
                this.pars.WinWidth = width;
                trackBarWinWidth.Value = Math.Min(this.pars.WindowRange.Max, Math.Max(this.pars.WindowRange.Min, width));
                userChanged = true;
            }
        }

        private void trackBarThinFac_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int fac = trackBarThinFac.Value;
                this.pars.ThinFactor = fac;
                numericUpDownThinFac.Value = Math.Min(this.pars.ThinRange.Max, Math.Max(this.pars.ThinRange.Min, fac));
                userChanged = true;
            }
        }

        private void numericUpDownThinFac_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int fac = (int)numericUpDownThinFac.Value;
                this.pars.ThinFactor = fac;
                trackBarThinFac.Value = Math.Min(this.pars.ThinRange.Max, Math.Max(this.pars.ThinRange.Min, fac));
                userChanged = true;
            }
        }

        private void buttonOK_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Dispose();
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Dispose();
        }
    }
}