using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ImageSharpApp.AlgProcessor.Forms
{
    partial class GrayContrastAdaptForm : Form
    {
        private bool userChanged = false;
        private GrayContrastAdaptParams pars = null;

        public GrayContrastAdaptParams Params
        {
            get
            {
                return this.pars;
            }
        }

        public GrayContrastAdaptForm(GrayContrastAdaptParams pars)
        {
            InitializeComponent();

            this.pars = pars;

            this.userChanged = false;
            trackBarPercLow.Minimum = pars.PxPercLowRange.Min;
            trackBarPercLow.Maximum = pars.PxPercLowRange.Max;
            trackBarPercLow.Value = pars.PxPercLow;
            trackBarPercHigh.Minimum = pars.PxPercHighRange.Min;
            trackBarPercHigh.Maximum = pars.PxPercHighRange.Max;
            trackBarPercHigh.Value = pars.PxPercHigh;
            trackBarPercLow.TickStyle = TickStyle.None;
            trackBarPercHigh.TickStyle = TickStyle.None;
            numericUpDownPercLow.Minimum = pars.PxPercLowRange.Min;
            numericUpDownPercLow.Maximum = pars.PxPercLowRange.Max;
            numericUpDownPercLow.Value = pars.PxPercLow;
            numericUpDownPercHigh.Minimum = pars.PxPercHighRange.Min;
            numericUpDownPercHigh.Maximum = pars.PxPercHighRange.Max;
            numericUpDownPercHigh.Value = pars.PxPercHigh;
            this.userChanged = true;
        }

        public GrayContrastAdaptForm()
        {
            InitializeComponent();
        }

        private void trackBarPercLow_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int perc = trackBarPercLow.Value;
                this.pars.PxPercLow = perc;
                numericUpDownPercLow.Value = Math.Min(this.pars.PxPercLowRange.Max, Math.Max(this.pars.PxPercLowRange.Min, perc));
                userChanged = true;
            }
        }

        private void trackBarPercHigh_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int perc = trackBarPercHigh.Value;
                this.pars.PxPercHigh = perc;
                numericUpDownPercHigh.Value = Math.Min(this.pars.PxPercHighRange.Max, Math.Max(this.pars.PxPercHighRange.Min, perc));
                userChanged = true;
            }
        }

        private void numericUpDownPercLow_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int perc = (int)numericUpDownPercLow.Value;
                this.pars.PxPercLow = perc;
                trackBarPercLow.Value = Math.Min(this.pars.PxPercLowRange.Max, Math.Max(this.pars.PxPercLowRange.Min, perc));
                userChanged = true;
            }
        }

        private void numericUpDownPercHigh_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int perc = (int)numericUpDownPercHigh.Value;
                this.pars.PxPercHigh = perc;
                trackBarPercHigh.Value = Math.Min(this.pars.PxPercHighRange.Max, Math.Max(this.pars.PxPercHighRange.Min, perc));
                userChanged = true;
            }
        }

        private void buttonOK_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Dispose();
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Dispose();
        }
    }
}