using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ImageSharpApp.AlgProcessor.Forms
{
    partial class GrayGammaCorrectionForm : Form
    {
        private bool userChanged = false;
        private GrayGammaCorrectionParams pars = null;

        public GrayGammaCorrectionParams Params
        {
            get
            {
                return this.pars;
            }
        }

        public GrayGammaCorrectionForm(GrayGammaCorrectionParams pars)
        {
            InitializeComponent();

            this.pars = pars;

            this.userChanged = false;
            trackBarA0.Minimum = pars.A0Range.Min;
            trackBarA0.Maximum = pars.A0Range.Max;
            trackBarA0.Value = pars.A0;
            trackBarGamma.Minimum = (int)(pars.GammaRange.Min * numericUpDownGamma.DecimalPlaces * 10f);
            trackBarGamma.Maximum = (int)(pars.GammaRange.Max * numericUpDownGamma.DecimalPlaces * 10f);
            trackBarGamma.Value = (int)(pars.Gamma * numericUpDownGamma.DecimalPlaces * 10f);
            trackBarA0.TickStyle = TickStyle.None;
            trackBarGamma.TickStyle = TickStyle.None;
            numericUpDownA0.Minimum = pars.A0Range.Min;
            numericUpDownA0.Maximum = pars.A0Range.Max;
            numericUpDownA0.Value = pars.A0;
            numericUpDownGamma.Minimum = (decimal)pars.GammaRange.Min;
            numericUpDownGamma.Maximum = (decimal)pars.GammaRange.Max;
            numericUpDownGamma.Value = (decimal)pars.Gamma;
            this.userChanged = true;
        }

        public GrayGammaCorrectionForm()
        {
            InitializeComponent();
        }

        private void trackBarA0_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                byte a0 = (byte)trackBarA0.Value;
                this.pars.A0 = a0;
                numericUpDownA0.Value = Math.Min(this.pars.A0Range.Max, Math.Max(this.pars.A0Range.Min, a0));
                userChanged = true;
            }
        }

        private void trackBarGamma_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                float gamma = trackBarGamma.Value / (numericUpDownGamma.DecimalPlaces * 10f);
                this.pars.Gamma = gamma;
                numericUpDownGamma.Value = (decimal)Math.Min(this.pars.GammaRange.Max, Math.Max(this.pars.GammaRange.Min, gamma));
                userChanged = true;
            }
        }

        private void numericUpDownA0_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                byte a0 = (byte)numericUpDownA0.Value;
                this.pars.A0 = a0;
                trackBarA0.Value = Math.Min(this.pars.A0Range.Max, Math.Max(this.pars.A0Range.Min, a0));
                userChanged = true;
            }
        }

        private void numericUpDownGamma_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                float gamma = (float)numericUpDownGamma.Value;
                this.pars.Gamma = gamma;
                trackBarGamma.Value = (int)Math.Min(this.pars.GammaRange.Max * numericUpDownGamma.DecimalPlaces * 10, Math.Max(this.pars.GammaRange.Min * numericUpDownGamma.DecimalPlaces * 10, gamma * numericUpDownGamma.DecimalPlaces * 10));
                userChanged = true;
            }
        }

        private void buttonOK_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Dispose();
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Dispose();
        }
    }
}